Remove candidate cluster from the study before running investment process
Source:R/Optim_H2_multi_nodes_functions.R
remove_candidate_cluster.RdRemove candidate cluster from the study before running investment process
Arguments
- opts
`list` Study parameters (typically the output of `antaresRead::setSimulationPath(simulation = "input")`).
- candidates_types_gen
`data.frame` A data.frame describing the generation candidates to be optimized. **See section ‘Structure of candidates_types_gen’ for details about required columns and their usage.**